package dev.fyloz.backup.utils

import dev.fyloz.backup.exceptions.ValidationException
import io.ktor.server.application.*
import io.ktor.util.pipeline.*

/**
 * Checks if a header with the [headerName] exists in the current request and returns its value, if present.
 * Throws a [ValidationException] if the header has not been set.
 */
fun PipelineContext<Unit, ApplicationCall>.validateAndGetHeader(headerName: String): String {
    if (headerName !in call.request.headers) {
        throw ValidationException("Header '$headerName' is required")
    }

    return call.request.headers[headerName]!!
}